@@ -207,8 +207,7 @@ class Document (Connector.Publisher):
 
         self.uim.ensure_update ()
 
-        
-        gp = os.path.join (version.pybdir, 'glade', 'pyblio.glade')
+        gp = os.path.join(Utils.glade_root, 'pyblio.glade')
         
         self.xml = gtk.glade.XML (gp, 'main', domain = 'pybliographer')
         self.xml.signal_autoconnect (self)
@@ -502,12 +501,16 @@ class Document (Connector.Publisher):
         self.issue ('new-document', self)
         return
 
+    def open_in_new(self, url, how=None, no_name=False):
+        ''' open a document in a new window '''
+        
+        self.issue('open-in-new', url, how, no_name)
+        return
+
 
     def query_database (self, * arg):
         ''' callback corresponding to the "Medline Query..." button '''
 
-        if not self.confirm (): return
-
         data = MedlineUI (self.w).run ()
         if data is None: return
         
@@ -518,7 +521,7 @@ class Document (Connector.Publisher):
             self.w.error (_("Your query returned no result"))
             return
         
-        self.open_document (url, 'medline', no_name = True)
+        self.open_in_new(url, 'medline', no_name=True)
         return
 
 
@@ -1219,7 +1222,7 @@ class Document (Connector.Publisher):
         about = ui.About ('Pybliographic',
                           version.version,
                           _("This program is copyrighted under the GNU GPL"),
-                          _("Gnome interface to the Pybliographer system."),
+                          _("GNOME interface to the Pybliographer system."),
                           ['Hervé Dréau',
                            'Frédéric Gobry',
                            'Zoltán Kóta',
@@ -1230,7 +1233,7 @@ class Document (Connector.Publisher):
                           ['Yuri Bongiorno',
                            'Frédéric Gobry',
                            'Zoltán Kóta'],
-                          _('Gnome Translation Team'))
+                          _('GNOME Translation Team'))
 
         about.set_transient_for (self.w)
         
