@@ -109,7 +109,7 @@ def list_entries (file):
             # we match a new citation
             match = citation_re.search (line)
             if match:
-                citations.append (match.group (1))
+                citations += [ref.strip() for ref in match.split(',')]
                 continue
 	
             # we have to enter an additional .aux file
